@@ -6,20 +6,19 @@ from io import BytesIO
 from itertools import zip_longest
 
 from lxml import etree
-from zeep.exceptions import Fault
 from PyPDF2 import PdfFileReader, PdfFileWriter
+from zeep.exceptions import Fault
 
 from trytond.i18n import gettext
-from trytond.pool import Pool, PoolMeta
 from trytond.model import fields
 from trytond.model.exceptions import AccessError
-from trytond.wizard import Wizard, StateAction, StateTransition
-from trytond.transaction import Transaction
-
 from trytond.modules.stock_package_shipping.exceptions import (
     PackingValidationError)
+from trytond.pool import Pool, PoolMeta
+from trytond.transaction import Transaction
+from trytond.wizard import StateAction, StateTransition, Wizard
 
-from .configuration import get_client, SHIPMENT_SERVICE
+from .configuration import SHIPMENT_SERVICE, get_client
 from .exceptions import DPDError
 
 TRACKING_URL = 'https://tracking.dpd.de/status/%(code)s/parcel/%(reference)s'
@@ -153,7 +152,10 @@ class CreateDPDShipping(Wizard):
                         count += 1
                         credential.update_token()
                         continue
-                raise
+                raise DPDError(gettext(
+                        'stock_package_shipping_dpd.'
+                        'msg_dpd_webservice_error',
+                        message=e.message)) from e
         else:
             raise DPDError(
                 gettext('stock_package_shipping_dpd.msg_dpd_login_error',
@@ -208,7 +210,7 @@ class CreateDPDShipping(Wizard):
             'paperFormat': shipment.carrier.dpd_paper_format,
             }
 
-    def shipping_party(self, party, address):
+    def shipping_party(self, party, address, usage=None):
         shipping_party = {
             'name1': address.party_full_name[:35],
             'name2': '',
@@ -220,10 +222,10 @@ class CreateDPDShipping(Wizard):
         if party.full_name != address.party_full_name:
             shipping_party['name2'] = party.full_name[:35]
 
-        phone = party.contact_mechanism_get({'phone', 'mobile'})
+        phone = party.contact_mechanism_get({'phone', 'mobile'}, usage=usage)
         if phone and len(phone.value) <= 30:
             shipping_party['phone'] = phone.value
-        email = party.contact_mechanism_get('email')
+        email = party.contact_mechanism_get('email', usage=usage)
         if email and len(email.value) <= 50:
             shipping_party['email'] = email.value
 
